==> eiffelstudio-18.11.10.2592.tar: F_code/C7/te304.c <==
/*
 * Code for class TEMPLATE_STRUCTURE_ACTION_FOREACH
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "te304.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.process */
void F810_6061 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	F801_6009(Current);
	F810_6065(Current);
	RTLE;
}

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.get_output */
void F810_6062 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F803_6033(Current);
}

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.process_foreach */
void F810_6065 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(12);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,loc3);
	RTLR(4,loc2);
	RTLR(5,loc1);
	RTLR(6,loc4);
	RTLR(7,loc6);
	RTLR(8,loc5);
	RTLR(9,loc8);
	RTLR(10,loc9);
	RTLR(11,loc7);
	RTLIU(12);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
	tr2 = RTOSCF(2933,F124_2933,(Current));
	tb1 = F606_5163(RTCW(tr1), tr2);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
		tr2 = RTOSCF(2933,F124_2933,(Current));
		loc3 = F606_5161(RTCW(tr1), tr2);
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
	tr2 = RTOSCF(2932,F124_2932,(Current));
	tb1 = F606_5163(RTCW(tr1), tr2);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
		tr2 = RTOSCF(2932,F124_2932,(Current));
		loc2 = F606_5161(RTCW(tr1), tr2);
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
	tr2 = RTOSCF(2931,F124_2931,(Current));
	tb1 = F606_5163(RTCW(tr1), tr2);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
		tr2 = RTOSCF(2931,F124_2931,(Current));
		loc1 = F606_5161(RTCW(tr1), tr2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
		tr2 = RTOSCF(2930,F124_2930,(Current));
		tb1 = F606_5163(RTCW(tr1), tr2);
		if (tb1) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
			tr2 = RTOSCF(2930,F124_2930,(Current));
			loc1 = F606_5161(RTCW(tr1), tr2);
		}
	}
	if ((EIF_BOOLEAN)(loc1 != NULL)) {
		loc4 = F801_6003(Current, loc1);
		if ((EIF_BOOLEAN)(loc4 != NULL)) {
			loc6 = (EIF_REFERENCE) NULL;
			loc5 = (EIF_REFERENCE) NULL;
			loc8 = RTCCL(loc4);
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFF01,302,0,0xFF01,878,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				loc8 = RTRV(typres0,loc8);
			}
			if (EIF_TEST(loc8)) {
				loc6 = (EIF_REFERENCE) loc8;
			} else {
				loc9 = RTCCL(loc4);
				{
					static EIF_TYPE_INDEX typarr0[] = {0xFF01,288,0,0xFFFF};
					EIF_TYPE typres0;
					static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
					
					typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
					loc9 = RTRV(typres0,loc9);
				}
				if (EIF_TEST(loc9)) {
					loc5 = (EIF_REFERENCE) loc9;
				}
			}
		}
	}
	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc6 != NULL) && (EIF_BOOLEAN) ((EIF_BOOLEAN)(loc3 != NULL) || (EIF_BOOLEAN)(loc2 != NULL)))) {
		loc7 = F810_6066(Current, loc6, loc3, loc2);
	} else {
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc5 != NULL) && (EIF_BOOLEAN)(loc2 != NULL))) {
			loc7 = F810_6067(Current, loc5, loc3, loc2);
		}
	}
	if ((EIF_BOOLEAN)(loc7 != NULL)) {
		F801_6021(Current, loc7);
	}
	RTLE;
}

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.foreach_hash_any_hashable_output */
EIF_REFERENCE F810_6066 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(11);
	RTLR(0,Result);
	RTLR(1,loc4);
	RTLR(2,arg1);
	RTLR(3,arg3);
	RTLR(4,loc2);
	RTLR(5,Current);
	RTLR(6,tr1);
	RTLR(7,tr2);
	RTLR(8,arg2);
	RTLR(9,loc3);
	RTLR(10,loc1);
	RTLIU(11);
	
	RTGC;
	Result = RTMS_EX_H("",0,0);
	loc4 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R4321[Dtype(arg1)-300])(RTCW(arg1));
	for (;;) {
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5004[Dtype(loc4)-674])(loc4);
		if (tb1) break;
		if ((EIF_BOOLEAN)(arg3 != NULL)) {
			loc2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5003[Dtype(loc4)-674])(loc4);
			tr1 = RTOSCF(3028,F135_3028,(Current));
			tr2 = RTCCL(loc2);
			F17_501(RTCW(tr1), tr2, arg3);
		}
		if ((EIF_BOOLEAN)(arg2 != NULL)) {
			loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5063[Dtype(loc4)-726])(loc4);
			tr1 = RTOSCF(3028,F135_3028,(Current));
			tr2 = RTCCL(loc3);
			F17_501(RTCW(tr1), tr2, arg2);
		}
		tr1 = F803_6038(Current);
		loc1 = F803_6039(Current, tr1, (EIF_BOOLEAN) 0);
		F1015_8667(RTCW(Result), loc1);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5005[Dtype(loc4)-674])(loc4);
	}
	if ((EIF_BOOLEAN)(arg3 != NULL)) {
		tr1 = RTOSCF(3028,F135_3028,(Current));
		F17_502(RTCW(tr1), arg3);
	}
	if ((EIF_BOOLEAN)(arg2 != NULL)) {
		tr1 = RTOSCF(3028,F135_3028,(Current));
		F17_502(RTCW(tr1), arg2);
	}
	RTLE;
	return Result;
}

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.foreach_list_any_output */
EIF_REFERENCE F810_6067 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(10);
	RTLR(0,Result);
	RTLR(1,loc4);
	RTLR(2,arg1);
	RTLR(3,arg3);
	RTLR(4,loc2);
	RTLR(5,Current);
	RTLR(6,tr1);
	RTLR(7,tr2);
	RTLR(8,arg2);
	RTLR(9,loc1);
	RTLIU(10);
	
	RTGC;
	loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	Result = RTMS_EX_H("",0,0);
	loc4 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R4321[Dtype(arg1)-300])(RTCW(arg1));
	for (;;) {
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5004[Dtype(loc4)-674])(loc4);
		if (tb1) break;
		loc3++;
		if ((EIF_BOOLEAN)(arg3 != NULL)) {
			loc2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5003[Dtype(loc4)-674])(loc4);
			tr1 = RTOSCF(3028,F135_3028,(Current));
			tr2 = RTCCL(loc2);
			F17_501(RTCW(tr1), tr2, arg3);
		}
		if ((EIF_BOOLEAN)(arg2 != NULL)) {
			tr1 = RTOSCF(3028,F135_3028,(Current));
			tr2 = RTLNS(eif_new_type(934, 0x00).id, 934, _OBJSIZ_0_0_0_1_0_0_0_0_);
			*(EIF_INTEGER_32 *)tr2 = loc3;
			F17_501(RTCW(tr1), tr2, arg2);
		}
		tr1 = F803_6038(Current);
		loc1 = F803_6039(Current, tr1, (EIF_BOOLEAN) 0);
		F1015_8667(RTCW(Result), loc1);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5005[Dtype(loc4)-674])(loc4);
	}
	if ((EIF_BOOLEAN)(arg3 != NULL)) {
		tr1 = RTOSCF(3028,F135_3028,(Current));
		F17_502(RTCW(tr1), arg3);
	}
	if ((EIF_BOOLEAN)(arg2 != NULL)) {
		tr1 = RTOSCF(3028,F135_3028,(Current));
		F17_502(RTCW(tr1), arg2);
	}
	RTLE;
	return Result;
}

void EIF_Minit304 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C7/te304.c <==
/*
 * Code for class TEMPLATE_STRUCTURE_ACTION_FOREACH
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "te304.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.process */
void F810_6062 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	{
		/* INLINED CODE (TEMPLATE_STRUCTURE_ITEM.process) */
		/* END INLINED CODE */
	}
	;
	F810_6066(Current);
	RTLE;
}

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.get_output */
void F810_6063 (EIF_REFERENCE Current)
{
	GTCX
	
	
	F806_6048(Current);
}

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.process_foreach */
void F810_6066 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc5 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc7 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc8 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc9 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTCFDT;
	RTLD;
	
	RTLI(12);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,loc3);
	RTLR(4,loc2);
	RTLR(5,loc1);
	RTLR(6,loc4);
	RTLR(7,loc6);
	RTLR(8,loc5);
	RTLR(9,loc8);
	RTLR(10,loc9);
	RTLR(11,loc7);
	RTLIU(12);
	
	RTGC;
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
	tr2 = RTOSCF(2940,F126_2940, (Current));
	tb1 = F608_5173(RTCW(tr1), tr2);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
		tr2 = RTOSCF(2940,F126_2940, (Current));
		loc3 = F608_5171(RTCW(tr1), tr2);
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
	tr2 = RTOSCF(2939,F126_2939, (Current));
	tb1 = F608_5173(RTCW(tr1), tr2);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
		tr2 = RTOSCF(2939,F126_2939, (Current));
		loc2 = F608_5171(RTCW(tr1), tr2);
	}
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
	tr2 = RTOSCF(2938,F126_2938, (Current));
	tb1 = F608_5173(RTCW(tr1), tr2);
	if (tb1) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
		tr2 = RTOSCF(2938,F126_2938, (Current));
		loc1 = F608_5171(RTCW(tr1), tr2);
	} else {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
		tr2 = RTOSCF(2937,F126_2937, (Current));
		tb1 = F608_5173(RTCW(tr1), tr2);
		if (tb1) {
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_8_);
			tr2 = RTOSCF(2937,F126_2937, (Current));
			loc1 = F608_5171(RTCW(tr1), tr2);
		}
	}
	if ((EIF_BOOLEAN)(loc1 != NULL)) {
		loc4 = F804_6018(Current, loc1);
		if ((EIF_BOOLEAN)(loc4 != NULL)) {
			loc6 = (EIF_REFERENCE) NULL;
			loc5 = (EIF_REFERENCE) NULL;
			loc8 = RTCCL(loc4);
			{
				static EIF_TYPE_INDEX typarr0[] = {0xFF01,304,0,0xFF01,881,0xFFFF};
				EIF_TYPE typres0;
				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
				
				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
				loc8 = RTRV(typres0,loc8);
			}
			if (EIF_TEST(loc8)) {
				loc6 = (EIF_REFERENCE) loc8;
			} else {
				loc9 = RTCCL(loc4);
				{
					static EIF_TYPE_INDEX typarr0[] = {0xFF01,290,0,0xFFFF};
					EIF_TYPE typres0;
					static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
					
					typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
					loc9 = RTRV(typres0,loc9);
				}
				if (EIF_TEST(loc9)) {
					loc5 = (EIF_REFERENCE) loc9;
				}
			}
		}
	}
	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc6 != NULL) && (EIF_BOOLEAN) ((EIF_BOOLEAN)(loc3 != NULL) || (EIF_BOOLEAN)(loc2 != NULL)))) {
		loc7 = F810_6067(Current, loc6, loc3, loc2);
	} else {
		if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc5 != NULL) && (EIF_BOOLEAN)(loc2 != NULL))) {
			loc7 = F810_6068(Current, loc5, loc3, loc2);
		}
	}
	if ((EIF_BOOLEAN)(loc7 != NULL)) {
		F804_6036(Current, loc7);
	}
	RTLE;
}

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.foreach_hash_any_hashable_output */
EIF_REFERENCE F810_6067 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(11);
	RTLR(0,Result);
	RTLR(1,loc4);
	RTLR(2,arg1);
	RTLR(3,arg3);
	RTLR(4,loc2);
	RTLR(5,Current);
	RTLR(6,tr1);
	RTLR(7,tr2);
	RTLR(8,arg2);
	RTLR(9,loc3);
	RTLR(10,loc1);
	RTLIU(11);
	
	RTGC;
	Result = RTMS_EX_H("",0,0);
	loc4 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R4330[Dtype(RTCW(arg1))-303])(arg1);
	for (;;) {
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5016[Dtype(loc4)-677])(loc4);
		if (tb1) break;
		if ((EIF_BOOLEAN)(arg3 != NULL)) {
			loc2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5015[Dtype(loc4)-677])(loc4);
			tr1 = RTOSCF(3038,F137_3038, (Current));
			tr2 = RTCCL(loc2);
			F17_501(RTCW(tr1), tr2, arg3);
		}
		if ((EIF_BOOLEAN)(arg2 != NULL)) {
			loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5075[Dtype(loc4)-729])(loc4);
			tr1 = RTOSCF(3038,F137_3038, (Current));
			tr2 = RTCCL(loc3);
			F17_501(RTCW(tr1), tr2, arg2);
		}
		tr1 = F806_6053(Current);
		loc1 = F806_6054(Current, tr1, (EIF_BOOLEAN) 0);
		F1018_8701(RTCW(Result), loc1);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5017[Dtype(loc4)-677])(loc4);
	}
	if ((EIF_BOOLEAN)(arg3 != NULL)) {
		tr1 = RTOSCF(3038,F137_3038, (Current));
		F17_502(RTCW(tr1), arg3);
	}
	if ((EIF_BOOLEAN)(arg2 != NULL)) {
		tr1 = RTOSCF(3038,F137_3038, (Current));
		F17_502(RTCW(tr1), arg2);
	}
	RTLE;
	return Result;
}

/* {TEMPLATE_STRUCTURE_ACTION_FOREACH}.foreach_list_any_output */
EIF_REFERENCE F810_6068 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc4 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(10);
	RTLR(0,Result);
	RTLR(1,loc4);
	RTLR(2,arg1);
	RTLR(3,arg3);
	RTLR(4,loc2);
	RTLR(5,Current);
	RTLR(6,tr1);
	RTLR(7,tr2);
	RTLR(8,arg2);
	RTLR(9,loc1);
	RTLIU(10);
	
	RTGC;
	loc3 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
	Result = RTMS_EX_H("",0,0);
	loc4 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R4330[Dtype(RTCW(arg1))-303])(arg1);
	for (;;) {
		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5016[Dtype(loc4)-677])(loc4);
		if (tb1) break;
		loc3++;
		if ((EIF_BOOLEAN)(arg3 != NULL)) {
			loc2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5015[Dtype(loc4)-677])(loc4);
			tr1 = RTOSCF(3038,F137_3038, (Current));
			tr2 = RTCCL(loc2);
			F17_501(RTCW(tr1), tr2, arg3);
		}
		if ((EIF_BOOLEAN)(arg2 != NULL)) {
			tr1 = RTOSCF(3038,F137_3038, (Current));
			tr2 = RTLNS(eif_new_type(940, 0x00).id, 940, _OBJSIZ_0_0_0_1_0_0_0_0_);
			*(EIF_INTEGER_32 *)tr2 = loc3;
			F17_501(RTCW(tr1), tr2, arg2);
		}
		tr1 = F806_6053(Current);
		loc1 = F806_6054(Current, tr1, (EIF_BOOLEAN) 0);
		F1018_8701(RTCW(Result), loc1);
		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5017[Dtype(loc4)-677])(loc4);
	}
	if ((EIF_BOOLEAN)(arg3 != NULL)) {
		tr1 = RTOSCF(3038,F137_3038, (Current));
		F17_502(RTCW(tr1), arg3);
	}
	if ((EIF_BOOLEAN)(arg2 != NULL)) {
		tr1 = RTOSCF(3038,F137_3038, (Current));
		F17_502(RTCW(tr1), arg2);
	}
	RTLE;
	return Result;
}

void EIF_Minit304 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
